;====================================================================
; V24 Moppel 87er Hardware
; Routinen aus BIOS
;
; Baudratentabelle fuer
; CPU-Frequenz 6,144MHz
;
; Teilfaktor fuer Timer
;	= CPU-Frequenz /2 = Systemtakt / 4800bd / 16 = 40
;                                                 I
;                                                 UART Teiler
;
; Wert als BCD, da Timer auf BCD Zaehler eingestellt wird
;               sonst Umrechnung nach Binaer notwendig
;
; 19200BD = 10 lowByte
;  9600Bd = 20 .
;  4800Bd = 40 .
;  2400Bd = 80 .
;  1200Bd = 60 lowByte
;	    01 highByte
;
; (DE) Baudrate laden
;
inibd:		lxi	d,0020h		; Startwert 9600Bd
;
; Baudrate laden (DE)
;
mv24bd:	mvi	a,37h		; Ctl Zaehler als BCD-Zaehler
		out	timer_c	;
		mov	a,e		;
		out 	timer_0	; Zaehler untere haelfte
		mov	a,d		;
		out 	timer_0	; Zaehler obere haelfte
		mvi 	a,48h		; v24 modus
		out 	cs_mode	;
		mvi 	a,55h		;
		out 	uart_c	; clk/16,8bit,1stop,ohne paritaet , RTS on
		mvi 	a,03		; Reset UART
		out 	uart_c		;
		ret
;
; V24 Input-Status
;	(A)=00h kein Zeichen
;	(A)=FFh Zeichen vorhanden
;
mv24ist:	mvi	a,15h		;
		out	uart_c	; clk/16,8bit,1stop,ohne paritaet , RTS off
mvist_l:	in	uart_c	; Warten bis Empfangsregister voll
		ani	01h		;
		jnz	mvist_e	; Zeichen vorhanden
		mvi	a,55h		; RTS on
		out	uart_c	;
		xra	a		;
		ret			;

mvist_e:	mvi 	a,55h		; RTS on
		out 	uart_c	;
		mvi 	a,0ffh	;
		ret			;
;
; Byte von V24 empfangen (A)
; wartet bis Zeichen vorhanden ist
;
mv24rx:	mvi	a,15h		;
		out	uart_c	; clk/16,8bit,1stop,ohne paritaet , RTS off
mvrx_l:	in	uart_c	; Warten bis Empfangsregister voll
		ani	01h		;
		jz	mvrx_l	; warten
		mvi	a,55h		; RTS on
		out	uart_c	;
		in	uart_d	; Daten auslesen
		ret			;
;
; Byte v24 senden (C)
; wartet bis Empfaenger bereit ist
;
mv24tx:	mvi 	a,55h		;
		out 	uart_c	; clk/16,8bit,1stop,ohne paritaet , RTS on
mvtx_l:	in 	uart_c	; Warten bis Senderegister leer
		ani 	02h		;
		jz	mvtx_l	;
		mov	a,c		;
		out 	uart_d	; Daten senden
		ret			;
;
; Byte V24 empfangen (A)
; mit Zeitueberwachung 10s (A)=1ah Control Z
;
mv24rxz:	push 	b		; ein Byte ueber V24 empfangen (A)
		lxi 	b,10000	; max Wartezeit 10s
		mvi 	a,15h		;
		out 	uart_c	; clk/16,8bit,1stop,ohne paritaet , RTS off
mvrxz_l:	in 	uart_c	; Warten bis Empfangsregister voll
		ani 	01h		;
		jnz  	mvrxz_e	;
		call 	dely1		; 1ms warten
		dcr	c		;
		jnz 	mvrxz_l	;
		dcr	b		;
		jnz	mvrxz_l	;
		pop 	b		;
		mvi	a,55h		; RTS on
		out	uart_c	;
		mvi 	a,1ah		; SUB (Control-Z)
		ret

mvrxz_e:	mvi	a,55h		; RTS on
		out	uart_c	;
		in	uart_d	; Daten auslesen
		pop	b		;
		ret			;
;
; Byte V24 senden (C)
; mit Zeitueberwachung
;
mv24txz:	mvi 	a,55h		; ein Byte ueber V24 senden (C)
		out 	uart_c	; clk/16,8bit,2stop,ohne paritaet RTS on
		mvi 	b,10		; max Wartezeit 10ms
mvtxz_l:	in 	uart_c	; Warten bis Senderegister leer
		ani 	02h		;
		jnz  	mvtxz_o	;
		call 	dely1		;
		dcr 	b		;
		jnz 	mvtxz_l		;
		mvi 	a,04h		; Zeituebschreitung (End of Transmission)
		ret			;
	;
mvtxz_o:	mov 	a,c		; Daten ausgeben
		out 	uart_d	;
		ret			;
;
;
;-----------------------------------------------------------------------------
